==> topk_sdk-0.1.21.tar.gz: topk_sdk-0.1.21/topk-rs/tests/test_get.rs <==
use test_context::test_context;
use topk_protos::doc;
use topk_rs::Error;

mod utils;
use utils::dataset;
use utils::ProjectTestContext;

#[test_context(ProjectTestContext)]
#[tokio::test]
async fn test_get_from_non_existent_collection(ctx: &mut ProjectTestContext) {
    let err = ctx
        .client
        .collection("missing")
        .get("doc1", vec![], None, None)
        .await
        .expect_err("should not be able to get document from non-existent collection");

    // TODO: this should return `CollectionNotFound`
    assert!(matches!(err, Error::DocumentNotFound));
}

#[test_context(ProjectTestContext)]
#[tokio::test]
async fn test_get_non_existent_document(ctx: &mut ProjectTestContext) {
    let collection = dataset::books::setup(ctx).await;

    let err = ctx
        .client
        .collection(&collection.name)
        .get("missing", vec![], None, None)
        .await
        .expect_err("should not be able to get non-existent document");

    assert!(matches!(err, Error::DocumentNotFound));
}

#[test_context(ProjectTestContext)]
#[tokio::test]
async fn test_get_document(ctx: &mut ProjectTestContext) {
    let collection = dataset::books::setup(ctx).await;

    let lotr = dataset::books::docs()
        .into_iter()
        .find(|doc| doc.id().unwrap() == "lotr")
        .clone()
        .unwrap();

    let doc = ctx
        .client
        .collection(&collection.name)
        .get("lotr", vec![], None, None)
        .await
        .expect("could not get document");

    assert_eq!(doc, lotr);
}

#[test_context(ProjectTestContext)]
#[tokio::test]
async fn test_get_document_fields(ctx: &mut ProjectTestContext) {
    let collection = dataset::books::setup(ctx).await;

    let doc = ctx
        .client
        .collection(&collection.name)
        .get(
            "lotr",
            vec!["title".to_string(), "published_year".to_string()],
            None,
            None,
        )
        .await
        .expect("could not get document");

    assert_eq!(
        doc,
        doc!("_id" => "lotr", "title" => "The Lord of the Rings: The Fellowship of the Ring", "published_year" => 1954 as u32)
    );
}

==> topk_sdk-0.1.22.tar.gz: topk_sdk-0.1.22/topk-rs/tests/test_get.rs <==
use std::collections::HashMap;

use test_context::test_context;
use topk_protos::doc;
use topk_rs::Error;

mod utils;
use utils::dataset;
use utils::ProjectTestContext;

#[test_context(ProjectTestContext)]
#[tokio::test]
async fn test_get_from_non_existent_collection(ctx: &mut ProjectTestContext) {
    let err = ctx
        .client
        .collection("missing")
        .get(["doc1"], None, None, None)
        .await
        .expect_err("should not be able to get document from non-existent collection");

    assert!(matches!(err, Error::CollectionNotFound));
}

#[test_context(ProjectTestContext)]
#[tokio::test]
async fn test_get_non_existent_document(ctx: &mut ProjectTestContext) {
    let collection = dataset::books::setup(ctx).await;

    let docs = ctx
        .client
        .collection(&collection.name)
        .get(["missing"], None, None, None)
        .await
        .expect("get failed");

    assert_eq!(docs, HashMap::new());
}

#[test_context(ProjectTestContext)]
#[tokio::test]
async fn test_get_document(ctx: &mut ProjectTestContext) {
    let collection = dataset::books::setup(ctx).await;

    let lotr = dataset::books::docs()
        .into_iter()
        .find(|doc| doc.id().unwrap() == "lotr")
        .clone()
        .unwrap();

    let docs = ctx
        .client
        .collection(&collection.name)
        .get(["lotr"], None, None, None)
        .await
        .expect("could not get document");

    assert_eq!(docs, HashMap::from([("lotr".to_string(), lotr.fields)]));
}

#[test_context(ProjectTestContext)]
#[tokio::test]
async fn test_get_multiple_documents(ctx: &mut ProjectTestContext) {
    let collection = dataset::books::setup(ctx).await;

    let docs = ctx
        .client
        .collection(&collection.name)
        .get(["lotr", "moby"], None, None, None)
        .await
        .expect("could not get documents");

    let lotr = dataset::books::docs()
        .into_iter()
        .find(|doc| doc.id().unwrap() == "lotr")
        .unwrap();
    let moby = dataset::books::docs()
        .into_iter()
        .find(|doc| doc.id().unwrap() == "moby")
        .unwrap();

    assert_eq!(
        docs,
        HashMap::from([
            ("lotr".to_string(), lotr.fields),
            ("moby".to_string(), moby.fields)
        ])
    );
}

#[test_context(ProjectTestContext)]
#[tokio::test]
async fn test_get_document_fields(ctx: &mut ProjectTestContext) {
    let collection = dataset::books::setup(ctx).await;

    let docs = ctx
        .client
        .collection(&collection.name)
        .get(
            ["lotr"],
            Some(vec!["title".to_string(), "published_year".to_string()]),
            None,
            None,
        )
        .await
        .expect("could not get document");

    assert_eq!(
        docs,
        HashMap::from([(
            "lotr".to_string(),
            doc!(
                "_id" => "lotr",
                "title" => "The Lord of the Rings: The Fellowship of the Ring",
                "published_year" => 1954 as u32
            )
            .fields
        )])
    );
}
